% Script included in the Online Material of:
% Mazzucchelli M.L.,  Angel R. J., Alvaro M. (2021) EntraPT: an online platform for elastic geothermobarometry.
% American Mineralogist, 10.2138/am-2021-7693CCBYNCND
%
% This script provides an example of how the project files of EntraPT can be processed with simple Matlab scripts
% With this script the user can reproduce the Figure OM6 reported 
% in the supplementary materials of Mazzucchelli et al. (2021).
%
%
% This scripts performs the following operations:
% 1) Import a project file (*.ept) generated by EntraPT.
% 2) Allows the user to choose a temperature (Tiso) on the isomeke and get the correspoding 
% pressure (Piso) for all or some of the analyses in the project.
% 3) Extract the residual stress in the inclusion for each analysis and
% compute the differential stress
% 4) Plot the Piso (at the choosen Tiso) of each analysis, as a function of
% the residual differential stress in the inclusion
% 

%% INPUT REQUIRED BY THE USER
% The user chooses the analyses to show in the plot by specifying a pattern (string).
% All the analyses whose labels contain this string will be extracted form
% the project.
% The user must also give a temperature on the isomeke whose corresponding
% pressure will be extracted for the plot.

pattern = 'Alm1'; % Extract only the analyses whose labels contain this string
Tiso    = 775; % Choose the Temperature on the isomeke at which you want to get the corresponding pressure (Piso). Warning: the chosen Tiso must be an actual
% Warning: the chosen Tiso must be actually contained in the data of the project, otherwise the script will 
% issue an error message asking to chose a different Tiso


% From this point no other input to the code is required by the user

%% Import the EntraPT project file

% Open the dialog to choose the project file (*.ept)
filter       = '.ept';
title        = 'Import project';
defname      = fullfile(pwd);
[file,path]  = uigetfile(filter,title,defname);

if ischar(file) % if the file is selected correctly go ahead
    project_fullpath = fullfile(path, file);
else % otherwise return
   error(['Project was not imported' newline 'Please try again']);
end

% Import the data and metadata
temp = load(project_fullpath,'-mat');
Project_EntraPT = temp.Project_EntraPT;

% Give a warning if the user tries to import project files with version
% later than 3
if ~strcmp(Project_EntraPT.Project_metadata.prj_version,'3')
    warning(['This script was released in May 2020. '...
        '\nAt that time EntraPT (version 1.0.0) supported project files with version 3'...
        '\nYou have imported a project file with version %s, therefore errors may arise during the execution of this script because of incompatibilities in the project file format.'...
        '\nTo test this script, please download the original project file provided in the Online Material of Mazzucchelli et al. (2021), American Mineralogist.'...
        '\nIf you have further questions, please contact us at software@mineralogylab.com'],Project_EntraPT.Project_metadata.prj_version )
end
    
%% Extract the Pressure on the isomeke at the given Tiso for all the requested analyses

all_analyses_labels        = [Project_EntraPT.Project_data.Calculations.Analysis_label]; % label of all the analyses in the project

% Get the position in the project of every analysis that contains the requested pattern.
position_required_analyses = find(contains(all_analyses_labels, pattern,'Ignorecase',true));

%Send an error if there are no analyses with the pattern given by the user
if isempty(position_required_analyses)
    error('This project does not contain any analysis with the required pattern "%s" \nPlease choose a different pattern or leave it empty',pattern);
end

% number of analyses that match the requirements
num_samples  = length(position_required_analyses);

samples      =(1:1:num_samples); %vector of increasing numbers from 1 to num_samples. It wil be used for plotting

% Initialize a table that will contain the labels, the Ptrap
% and the deviatoric stress of each analysis
TOutput      = table('Size',[num_samples 4],'Variablenames', {'Analysis_label', 'Differential_stress', 'Piso_eos', 'Piso_Cij'},...
    'VariableTypes',{'string', 'double', 'double', 'double'});  


% Get the labels, the Ptrap
% and the Differential stress of each analysis
% and store them in the table
for i =1:num_samples
    
    % extract the label
    TOutput.Analysis_label(i)         = Project_EntraPT.Project_data.Calculations(position_required_analyses(i)).Analysis_label; 
    
    % extract the residual stress
    residual_stress_current_sample    = (Project_EntraPT.Project_data.Calculations(position_required_analyses(i)).Calculation_parameters.stress_relaxed);
    
    % compute the differential stress
    TOutput.Differential_stress(i)    = max(residual_stress_current_sample(1:3))-min(residual_stress_current_sample(1:3));
    
    % Extract the T and P of all the isomekes of the current analysis
    Isomekes_current_sample           = Project_EntraPT.Project_data.Calculations(position_required_analyses(i)).Results.isomekes;
    
    % Find the Piso corresponding to the Tiso given by the user
    condition_eos                     = find(abs(Isomekes_current_sample.Ttrap_iso_eos-Tiso)<0.01);
    condition_Cij                     = find(abs(Isomekes_current_sample.Ttrap_iso_Cij - Tiso)<0.01);
    
    % If the Tiso is not included in the data issue an error and return
    if isempty(condition_eos) || isempty(condition_Cij) 
        error('The choosen T=%.0f is not a valid temperature on the isomekes of the selected analyses\nPlease choose a different Tiso', Tiso) ;
    end
    
    TOutput.Piso_eos(i)               = Isomekes_current_sample.Ptrap_iso_eos(condition_eos);
    TOutput.Piso_Cij(i)               = Isomekes_current_sample.Ptrap_iso_Cij(condition_Cij); 
    
end

% Sort the rows of the table by the value of Differential stress, from smaller
% to larger
TOutput = sortrows(TOutput,2);
%% Plot data

% Plot the shaded area of the values expected from the synthesis conditions
shaded_area       = fill([0 num_samples+1  num_samples+1 0], [2.8 2.8 3.2 3.2], 'k');
set(shaded_area,'facealpha',.3, 'EdgeColor', 'none'); %set the trasparency of the shaded area
hold on
% Plot the line representing the experimental pressure
line_plot         = plot( [0 num_samples+1], [3 3],'k');
hold on

% Plot the pressures
% The color of the symbol is proportional to the Differential stress of that
% analysis
Peos_plot         = scatter(samples, TOutput.Piso_eos,[], TOutput.Differential_stress,'>', 'filled');
hold on
Pcij_plot         = scatter(samples, TOutput.Piso_Cij,[],TOutput.Differential_stress,'o','filled');

ax                = gca;

% Set the x limit of the plot. Leave one extra void space on the right side
% of the plot
xlim([0 num_samples+1]);
% Put one tick for each analysis on the x axis
xticks(samples);
% Write the label of each analysis and tilt them
xticklabels(TOutput.Analysis_label);
xtickangle(60);
ax.TickLabelInterpreter= 'none';

% Set the y limits of the plot
ylimits          = [1.9 4.1];
ylim(ylimits)
% Set the y ticks
yticks((ceil(ylimits(1)):0.2:floor(ylimits(2))));
% Set the y axis label
ylabel('Calculated P_{trap} (GPa) at 775C')

% Set the colormap to represent the Differential stress
colormap(parula)
c                = colorbar('northoutside');
c.Label.String   = 'Differential stress (GPa)';
c.Label.FontSize = 13;

% Add the grid and the box
grid on
box on

% Add the legend
legend([line_plot Peos_plot Pcij_plot],{'Experimental pressure','P_{trap}^V','P_{trap}^{strain}',},'Location','southwest')
